@@ -18,10 +18,12 @@ class Verifier:
         if times is not None:
             if len(calls) == times:
                 return None
+
         else:
-            for i, call in enumerate(calls):
+            for i in range(len(calls)):
                 calls_subset = calls[i : i + len(rehearsals)]
-                if all(r == calls_subset[j] for j, r in enumerate(rehearsals)):
+
+                if calls_subset == rehearsals:
                     return None
 
         raise VerifyError(
